@@ -12,7 +12,7 @@
 dropRows <- function (dataset, expr) {
     if (!length(expr)) {
         ## Could be NULL or like NULL == something, which is logical(0)
-        halt("Invalid expression: ", deparse(match.call()$expr)[1])
+        halt("Invalid expression: ", deparseAndFlatten(match.call()$expr))
     }
     payload <- list(command="delete", filter=zcl(expr))
     out <- crPOST(shojiURL(dataset, "fragments", "table"), body=toJSON(payload))
