@@ -178,14 +178,32 @@ formatExpression <- function (expr) {
         ## GET URL, get alias from that
         return(crGET(expr[["variable"]])$body$alias)
     } else if (length(intersect(c("column", "value"), names(expr)))) {
-        val <- expr$column %||% expr$value
-        return(deparse(val))
+        return(deparseAndFlatten(expressionValue(expr)))
     } else {
         ## Dunno what this is
         return("[Complex expression]")
     }
 }
 
+expressionValue <- function (expr) {
+    ## Could be under either "column" or "value". R doesn't distinguish length-1
+    ## from length-N values, but Crunch API does.
+    unlist(expr$column %||% expr$value)
+}
+
+deparseAndFlatten <- function (x, max_length = NULL, ...) {
+    out <- deparse(x, ...)
+    if (length(out) > 1) {
+        out <- paste0(out, collapse="")
+    }
+    # if max_length is null, do nothing
+    # else return 1:max_length of out
+    if (!is.null(max_length)) {
+        out <- substr(out, 1, max_length)
+    }
+    return(out)
+}
+
 formatExpressionArgs <- function (args) {
     ## This is just to pretty-print category values as "names"
     ## Look for "variables"
@@ -194,7 +212,7 @@ formatExpressionArgs <- function (args) {
     if (sum(vars) == 1) {
         ## Great, let's see if we have any values to format
         vals <- vapply(args, function (x) {
-                length(names(x)) == 1 && names(x) %in% c("column", "value")
+                any(names(x) %in% c("column", "value"))
             }, logical(1))
         if (any(vals)) {
             ## Get the var, see if it is categorical
@@ -211,13 +229,13 @@ formatExpressionArgs <- function (args) {
 }
 
 formatExpressionValue <- function (val, cats=NULL) {
-    val <- val$column %||% val$value
+    val <- expressionValue(val)
     if (length(cats)) {
         val <- i2n(val, cats)
     } else {
         ## TODO: iterate over, replace {?:-1} with NA
     }
-    return(deparse(val))
+    return(deparseAndFlatten(val))
 }
 
 #' @rdname show-crunch
@@ -236,6 +254,19 @@ setMethod("show", "CrunchLogicalExpr", function (object) {
     invisible(object)
 })
 
+showMultitable <- function (x) {
+    out <- paste("Multitable", dQuote(name(x)))
+    
+    # TODO: check variable types to alert users in a more friendly manner
+    # eg remove selected_array()
+    out <- c(out, "Column variables:",
+             vapply(x@body$template, function (expr) {
+                 paste0("  ", formatExpression(expr$query[[1]]))
+             }, character(1)))
+    
+    return(c(out))
+}
+
 # More boilerplate
 
 setMethod("getShowContent", "Category", showCategory)
@@ -245,6 +276,7 @@ setMethod("getShowContent", "CategoricalArrayVariable",
     showCategoricalArrayVariable)
 setMethod("getShowContent", "CrunchDataset", showCrunchDataset)
 setMethod("getShowContent", "Subvariables", showSubvariables)
+setMethod("getShowContent", "Multitable", showMultitable)
 setMethod("getShowContent", "ShojiOrder", showShojiOrder)
 setMethod("getShowContent", "VariableOrder",
     function (x) showShojiOrder(x, key=namekey(x)))
@@ -271,7 +303,6 @@ setMethod("getShowContent", "CrunchFilter",
         return(c(paste("Crunch filter", dQuote(name(x))),
             paste("Expression:", formatExpression(expr(x)))))
     })
-
 #' @rdname show-crunch
 #' @export
 setMethod("show", "CrunchCube", function (object) show(cubeToArray(object)))
