@@ -1,7 +1,7 @@
 context("Appending datasets with arrays")
 
 with_test_authentication({
-    describe("when appending identical datasets with arrays", {
+    whereas("when appending identical datasets with arrays", {
         part1 <- mrdf.setup(newDataset(mrdf), selections="1.0")
         part2 <- mrdf.setup(newDataset(mrdf), selections="1.0")
         test_that("they get set up correctly", {
@@ -25,7 +25,7 @@ with_test_authentication({
                 "All good :)")
         })
         test_that("they append successfully", {
-            out <- appendDataset(part1, part2)
+            out <- appendDataset(part1, part2, autorollback=FALSE)
             expect_true(is.dataset(out))
             expect_length(batches(out), 3)
             expect_identical(dim(out), c(nrow(mrdf)*2L, 2L))
@@ -38,7 +38,7 @@ with_test_authentication({
     })
 
 
-    describe("When appending arrays with sparse data", {
+    whereas("When appending arrays with sparse data", {
         part1 <- newDataset(data.frame(v4=factor(rep(c("a", "b"), 500))))
         part2 <- mrdf.setup(newDataset(data.frame(
                             mr_1=c(1,0,1,1,0, rep(NA, 995)),
@@ -70,7 +70,7 @@ with_test_authentication({
         })
     })
 
-    test_that("alias and name matching on appending arrays", {
+    whereas("Appending arrays with mismatching names and aliases", {
         part1 <- mrdf.setup(newDataset(mrdf), selections="1.0")
         names(subvariables(part1$MR)) <- c("One", "Two", "Three")
         ## Aliases are c("mr_1", "mr_2", "mr_3")
@@ -79,27 +79,31 @@ with_test_authentication({
         aliases(subvariables(part2$MR))[3] <- "alt"
         ## Aliases are c("mr_1", "mr_2", "alt")
 
-        expect_output(summary(compareDatasets(part1, part2)),
-            paste(
-                "Mismatched names: 2 ",
-                " name.A alias name.B",
-                "  Three  mr_3   <NA>",
-                "   <NA>   alt  Three",
-                sep="\n"))
+        test_that("compareDatasets sees the mismatch", {
+            expect_output(summary(compareDatasets(part1, part2)),
+                paste(
+                    "Mismatched names: 2 ",
+                    " name.A alias name.B",
+                    "  Three  mr_3   <NA>",
+                    "   <NA>   alt  Three",
+                    sep="\n"))
+        })
 
         out <- appendDataset(part1, part2)
-        expect_true(is.dataset(out))
-        expect_length(batches(out), 3)
-        expect_identical(dim(out), c(nrow(mrdf)*2L, 2L))
-        expect_true(is.Multiple(out$MR))
-        skip("We get 2 'Threes'")
-        expect_equivalent(as.array(crtabs(~ MR, data=out)),
-            array(c(4, 2, 2), dim=c(3L),
-            dimnames=list(MR=c("One", "Two", "Three"))))
+
+        test_that("We can append despite the duplicate name", {
+            expect_true(is.dataset(out))
+            expect_length(batches(out), 3)
+            expect_identical(dim(out), c(nrow(mrdf)*2L, 2L))
+            expect_true(is.Multiple(out$MR))
+            skip("We get 2 'Threes'")
+            expect_equivalent(as.array(crtabs(~ MR, data=out)),
+                array(c(4, 2, 2), dim=c(3L),
+                dimnames=list(MR=c("One", "Two", "Three"))))
+        })
     })
 
-    purgeEntitiesCreated() ## Temporary fix for local resource limitation
-    describe("When appending and reverting and reloading", {
+    whereas("When appending and reverting and reloading", {
         part1 <- newDatasetFromFixture("apidocs")
         test_that("Setup for testing references post append", {
             expect_true(name(part1$allpets) == "All pets owned")
