@@ -3,7 +3,7 @@ context("Combine responses")
 # expect_error(ds$combined_mr <- combine(ds$mymrset, name="MR combined",
 #     list(list(name="Extremes", responses=c("First", "Last")))),
 #     mr.payload, fixed=TRUE)
-with_mock_HTTP({
+with_mock_crunch({
     ds <- loadDataset("test ds")
 
     extremes <- VariableDefinition(
