@@ -17,7 +17,7 @@ join <- function (...) {
     invisible(out)
 }
 
-with_mock_HTTP({
+with_mock_crunch({
     ds1 <- loadDataset("test ds")
     ds2 <- loadDataset("ECON.sav")
 
