@@ -5,7 +5,7 @@ test_that("default name for formula", {
     expect_identical(formulaRHS("a+b~c+d+rollup(e)"), "c+d+rollup(e)")
 })
 
-with_mock_HTTP({
+with_mock_crunch({
     ds <- loadDataset("test ds")   ## Has 2 multitables
     ds2 <- loadDataset("ECON.sav") ## Has no multitables
 
@@ -53,7 +53,8 @@ with_mock_HTTP({
     })
 
     test_that("newMultitable", {
-        expect_POST(newMultitable(~ gender + mymrset, data=ds, name="New multitable"),
+        expect_POST(newMultitable(~ gender + mymrset, data=ds,
+                                  name="New multitable"),
             'https://app.crunch.io/api/datasets/1/multitables/',
             '{"element":"shoji:entity","body":{',
             '"name":"New multitable",',
@@ -65,7 +66,8 @@ with_mock_HTTP({
             '"variable":"https://app.crunch.io/api/datasets/1/variables/mymrset/"}]',
             '}}')
         with_POST("https://app.crunch.io/api/datasets/1/multitables/4de322/", {
-            mtable <- newMultitable(~ gender + mymrset, data=ds, name="New multitable")
+            mtable <- newMultitable(~ gender + mymrset, data=ds,
+                                    name="New multitable")
             expect_is(mtable, "Multitable")
         })
     })
@@ -83,10 +85,37 @@ with_mock_HTTP({
             '"variable":"https://app.crunch.io/api/datasets/1/variables/mymrset/"}]',
             '}}')
         with_POST("https://app.crunch.io/api/datasets/1/multitables/4de322/", {
-            mtable <- newMultitable(~ gender + mymrset, data=ds, name="New multitable")
+            mtable <- newMultitable(~ gender + mymrset, data=ds,
+                                    name="New multitable")
             expect_is(mtable, "Multitable")
         })
     })
+    
+    test_that("importMultitable", {
+        with_POST("https://app.crunch.io/api/datasets/1/multitables/4de322/", {
+            mtable <- newMultitable(~ gender + mymrset, data=ds,
+                                    name="New multitable")
+            expect_is(mtable, "Multitable")
+        })
+        expect_POST(importMultitable(ds, mtable, name='copied_multitable'),
+                    'https://app.crunch.io/api/datasets/1/multitables/',
+                    '{"element":"shoji:entity","body":{', 
+                    '"multitable":"https://app.crunch.io/api/datasets/1/multitables/4de322/",',
+                    '"name":"copied_multitable"}}')
+    })
+    
+    test_that("multitable show method", {
+        with_POST("https://app.crunch.io/api/datasets/1/multitables/4de322/", {
+            mtable <- newMultitable(~ gender + mymrset, data=ds,
+                                    name="Shared multitable")
+            expect_is(mtable, "Multitable")
+        })
+        expect_output(mtable, 
+                      paste(paste0("Multitable ", dQuote("Shared multitable")),
+                                   "Column variables:",
+                                   "  gender",
+                                   "  mymrset", sep="\n"))
+    })
 
     test_that("newMultitable validation", {
         expect_error(newMultitable(), "Must provide a formula")
@@ -100,7 +129,6 @@ with_mock_HTTP({
         expect_null(weight(ds))
     })
     test_that("tabBook sets the right request header", {
-        skip("Too much mocking and tracing")
         expect_header(
             expect_POST(tabBook(m, data=ds, format="xlsx"),
                 'https://app.crunch.io/api/datasets/1/multitables/ed30c4/tabbook/'),
@@ -190,6 +218,7 @@ with_mock_HTTP({
 
 with_test_authentication({
     ds <- newDatasetFromFixture("apidocs")
+    ds2 <- newDatasetFromFixture("apidocs")
     test_that("Multitable catalog", {
         expect_is(multitables(ds), "MultitableCatalog")
         expect_length(multitables(ds), 0)
@@ -198,9 +227,14 @@ with_test_authentication({
     test_that("Can make a multitable", {
         m <- newMultitable(~ allpets + q1, data=ds)
         expect_identical(name(m), "allpets + q1")
+        expect_identical(getShowContent(m), c(paste0("Multitable ", dQuote("allpets + q1")),
+                                              "Column variables:",
+                                              "  selected_array(allpets)",
+                                              "  q1"))
     })
 
     mult <- multitables(ds)[["allpets + q1"]]
+
     test_that("Can make the multitable entity public/personal", {
         expect_false(is.public(mult))
         is.public(mult) <- TRUE
@@ -228,6 +262,22 @@ with_test_authentication({
         expect_identical(names(refresh(multitables(ds))), "Yet another name")
     })
 
+    test_that("Can copy the multitable to a new multitable", {
+        m <- importMultitable(ds2, mult, name='copied_multitable')
+        expect_identical(name(m), "copied_multitable")
+        is.public(multitables(ds2))[1] <- TRUE
+        expect_true(is.public(refresh(m)))
+        expect_identical(getShowContent(m), c(paste0("Multitable ", dQuote("copied_multitable")),
+                                              "Column variables:",
+                                              "  selected_array(allpets)",
+                                              "  q1"))
+    })
+    
+    test_that("importMultitable works without a name", {
+        m <- importMultitable(ds2, mult)
+        expect_identical(name(m), "Yet another name")
+    })
+
     test_that("We can get an xlsx tab book", {
         skip_locally("Vagrant host doesn't serve files correctly")
         f <- tempfile()
