@@ -1,6 +1,6 @@
 context("Subvariables")
 
-with_mock_HTTP({
+with_mock_crunch({
     ds <- loadDataset("test ds")
     mr <- ds$mymrset
 
