@@ -1,6 +1,6 @@
 context("User stuff")
 
-with_mock_HTTP({
+with_mock_crunch({
     test_that("Getting user object", {
         expect_is(me(), "UserEntity")
         expect_identical(email(me()), "fake.user@example.com")
