@@ -1,6 +1,6 @@
 context("Variables")
 
-with_mock_HTTP({
+with_mock_crunch({
     ds <- loadDataset("test ds")
     ds2 <- loadDataset("an archived dataset", "archived")
 
